export type Ring = 'purine'|'pyrimidine';

/* eslint-disable array-bracket-spacing, no-multi-spaces */
export const ReferenceCompounds: Record<string, [string, string]> = {
    AA00: [ 'A',  'G'],
    AA01: ['DC', 'DG'],
    AA02: ['DA', 'DA'],
    AA03: [ 'U',  'C'],
    AA04: [ 'A',  'G'],
    AA05: [ 'A',  'G'],
    AA06: [ 'U',  'G'],
    AA07: [ 'U',  'A'],
    AA08: [ 'G',  'C'],
    AA09: [ 'A',  'A'],
    AA10: [ 'A',  'G'],
    AA11: [ 'A',  'A'],
    AA12: [ 'U',  'G'],
    AA13: [ 'G',  'U'],
    AB01: ['DC', 'DG'],
    AB02: ['DG', 'DG'],
    AB03: ['DC', 'DA'],
    AB04: ['DT', 'DA'],
    AB05: [ 'G',  'U'],
    BA01: ['DA', 'DT'],
    BA05: ['DA', 'DC'],
    BA09: ['DG', 'DG'],
    BA08: ['DC', 'DG'],
    BA10: ['DA', 'DG'],
    BA13: ['DG', 'DA'],
    BA16: [ 'U',  'U'],
    BA17: ['DC', 'DT'],
    BB00: ['DG', 'DA'],
    BB01: ['DA', 'DA'],
    BB17: ['DC', 'DC'],
    BB02: ['DA', 'DC'],
    BB03: ['DA', 'DG'],
    BB11: ['DT', 'DT'],
    BB16: ['DC', 'DG'],
    BB04: ['DC', 'DG'],
    BB05: ['DA', 'DC'],
    BB07: ['DC', 'DG'],
    BB08: ['DC', 'DG'],
    BB10: ['DG', 'DG'],
    BB12: ['DG', 'DA'],
    BB13: ['DA', 'DC'],
    BB14: ['DC', 'DA'],
    BB15: ['DG', 'DC'],
    BB20: ['DT', 'DT'],
    IC01: [ 'C',  'C'],
    IC02: [ 'U',  'U'],
    IC03: [ 'G',  'A'],
    IC04: ['DC', 'DG'],
    IC05: ['DC', 'DG'],
    IC06: ['DC', 'DG'],
    IC07: [ 'G',  'U'],
    OP01: [ 'C',  'A'],
    OP02: [ 'G',  'U'],
    OP03: [ 'G',  'A'],
    OP04: [ 'G',  'A'],
    OP05: [ 'G',  'U'],
    OP06: [ 'U',  'U'],
    OP07: [ 'G',  'C'],
    OP08: [ 'G',  'A'],
    OP09: [ 'U',  'U'],
    OP10: [ 'G',  'A'],
    OP11: [ 'A',  'G'],
    OP12: [ 'U',  'C'],
    OP13: [ 'U',  'G'],
    OP14: [ 'A',  'G'],
    OP15: [ 'G',  'U'],
    OP16: [ 'G',  'G'],
    OP17: [ 'G',  'U'],
    OP18: [ 'U',  'U'],
    OP19: ['DG', 'DT'],
    OP20: ['DA', 'DC'],
    OP21: [ 'U',  'U'],
    OP22: ['DU', 'DU'],
    OP23: [ 'A',  'G'],
    OP24: [ 'A',  'A'],
    OP25: [ 'A',  'U'],
    OP26: [ 'U',  'C'],
    OP27: [ 'C',  'G'],
    OP28: [ 'G',  'U'],
    OP29: [ 'A',  'U'],
    OP30: [ 'C',  'G'],
    OP31: [ 'A',  'G'],
    OPS1: [ 'U',  'C'],
    OP1S: ['DT', 'DG'],
    AAS1: [ 'C',  'A'],
    AB1S: ['DA', 'DG'],
    AB2S: [ 'G',  'G'],
    BB1S: ['DG', 'DG'],
    BB2S: ['DG', 'DG'],
    BBS1: ['DG', 'DG'],
    ZZ01: [ 'U',  'C'],
    ZZ02: [ 'A',  'C'],
    ZZ1S: ['DC', 'DG'],
    ZZ2S: ['DC', 'DG'],
    ZZS1: ['DG', 'DC'],
    ZZS2: ['DG', 'DC'],
};
export type ReferenceCompounds = typeof ReferenceCompounds;

/* eslint-disable no-multi-spaces */
export const CompoundRings: Record<string, Ring> = {
    A:     'purine',
    G:     'purine',
    DA:    'purine',
    DG:    'purine',
    DDG:   'purine',
    EDA:   'purine',
    GNE:   'purine',
    N2G:   'purine',
    N5I:   'purine',
    '2DA': 'purine',
    '7DA': 'purine',
    PRN:   'purine',
    AD2:   'purine',
    A3P:   'purine',
    A5L:   'purine',
    FMG:   'purine',
    MA7:   'purine',
    MG1:   'purine',
    O2G:   'purine',
    PPW:   'purine',
    '1AP': 'purine',
    '2FI': 'purine',
    '2PR': 'purine',
    '6MA': 'purine',
    '6OG': 'purine',
    '7GU': 'purine',
    '8OG': 'purine',
    TGP:   'purine',
    GFL:   'purine',
    A2M:   'purine',
    OMG:   'purine',
    GTP:   'purine',
    GDP:   'purine',
    '2MG': 'purine',
    G7M:   'purine',
    IGU:   'purine',
    '6NW': 'purine',
    T:     'pyrimidine',
    C:     'pyrimidine',
    U:     'pyrimidine',
    DT:    'pyrimidine',
    '2DT': 'pyrimidine',
    '5NC': 'pyrimidine',
    DC:    'pyrimidine',
    DU:    'pyrimidine',
    BRU:   'pyrimidine',
    CBR:   'pyrimidine',
    C38:   'pyrimidine',
    DOC:   'pyrimidine',
    ME6:   'pyrimidine',
    OMC:   'pyrimidine',
    UMP:   'pyrimidine',
    Z:     'pyrimidine',
    '5CM': 'pyrimidine',
    '5IU': 'pyrimidine',
    '5PY': 'pyrimidine',
    PST:   'pyrimidine',
    SPT:   'pyrimidine',
    TPC:   'pyrimidine',
    TSP:   'pyrimidine',
    UPS:   'pyrimidine',
    US1:   'pyrimidine',
    '4PC': 'pyrimidine',
    '5HU': 'pyrimidine',
    '5FC': 'pyrimidine',
    UFT:   'pyrimidine',
    CFL:   'pyrimidine',
    TAF:   'pyrimidine',
    '5HC': 'pyrimidine',
    CCC:   'pyrimidine',
    IMC:   'pyrimidine',
    '5BU': 'pyrimidine',
    '6OO': 'pyrimidine',
    F2T:   'pyrimidine',
    XFC:   'pyrimidine'
};
export type CompoundRings = typeof CompoundRings;

export const BackboneAtoms = {
    first: ["C5'", "C4'", "O4'", "C3'", "O3'", "C1'"],
    /* eslint-disable @typescript-eslint/quotes */
    second: ["P", "O5'", "C5'", "C4'", "O4'", "C3'", "O3'", "C1'"],
    purine: ['N9', 'C4'],
    pyrimidine: ['N1', 'C2'],
};
